@@ -1021,7 +1021,7 @@ _gth_file_source_catalogs_copy_catalog (CopyCatalogData      *ccd,
 	_g_copy_files_async (gio_list,
 			     gio_destination,
 			     ccd->move,
-			     G_FILE_COPY_NONE,
+			     GTH_FILE_COPY_DEFAULT,
 			     default_response,
 			     G_PRIORITY_DEFAULT,
 			     gth_file_source_get_cancellable (ccd->file_source),
