@@ -99,13 +99,14 @@
 
 int   gth_albumtheme_yylex   (void);
 void  gth_albumtheme_yyerror (const char *fmt, ...);
+void  gth_albumtheme_yyfatalerror (const char *msg);
 int   gth_albumtheme_yywrap  (void);
 
 #define YY_NO_UNPUT
 #define YYERROR_VERBOSE 1
 
 
-#line 109 "albumtheme.c" /* yacc.c:339  */
+#line 110 "albumtheme.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -164,7 +165,7 @@ extern int gth_albumtheme_yydebug;
 
 union YYSTYPE
 {
-#line 36 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:355  */
+#line 37 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:355  */
 
 	char         *text;
 	int           ivalue;
@@ -175,7 +176,7 @@ union YYSTYPE
 	GthCondition *cond;
 	GthLoop      *loop;
 
-#line 179 "albumtheme.c" /* yacc.c:355  */
+#line 180 "albumtheme.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -192,7 +193,7 @@ int gth_albumtheme_yyparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 196 "albumtheme.c" /* yacc.c:358  */
+#line 197 "albumtheme.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -491,11 +492,11 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    76,    76,    85,    90,    94,    98,   106,   119,   123,
-     130,   143,   153,   157,   162,   167,   172,   176,   181,   193,
-     198,   201,   204,   209,   257,   267,   271,   276,   281,   287,
-     295,   299,   303,   308,   312,   325,   338,   351,   364,   377,
-     390,   394,   399,   404,   421,   428,   435
+       0,    77,    77,    86,    91,    95,    99,   107,   120,   124,
+     131,   144,   154,   158,   163,   168,   173,   177,   182,   194,
+     199,   202,   205,   210,   258,   268,   272,   277,   282,   288,
+     296,   300,   304,   309,   313,   326,   339,   352,   365,   378,
+     391,   395,   400,   405,   422,   429,   436
 };
 #endif
 
@@ -1356,7 +1357,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 76 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 77 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			yy_parsed_doc = (yyvsp[0].list);
 			if (yy_parsed_doc == NULL)
@@ -1364,36 +1365,36 @@ yyreduce:
 			else
 				YYACCEPT;
 		}
-#line 1368 "albumtheme.c" /* yacc.c:1646  */
+#line 1369 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 85 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 86 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), gth_tag_new_html ((yyvsp[-1].text)));
 			g_free ((yyvsp[-1].text));
 		}
-#line 1377 "albumtheme.c" /* yacc.c:1646  */
+#line 1378 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 90 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 91 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), (yyvsp[-1].tag));
 		}
-#line 1385 "albumtheme.c" /* yacc.c:1646  */
+#line 1386 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 94 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 95 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), (yyvsp[-1].tag));
 		}
-#line 1393 "albumtheme.c" /* yacc.c:1646  */
+#line 1394 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 98 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 99 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthTag *tag;
 
@@ -1401,11 +1402,11 @@ yyreduce:
 			tag = gth_tag_new_loop ((yyvsp[-3].loop));
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), tag);
 		}
-#line 1405 "albumtheme.c" /* yacc.c:1646  */
+#line 1406 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 106 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 107 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GList  *cond_list;
 			GthTag *tag;
@@ -1418,29 +1419,29 @@ yyreduce:
 			tag = gth_tag_new_condition (cond_list);
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), tag);
 		}
-#line 1422 "albumtheme.c" /* yacc.c:1646  */
+#line 1423 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 119 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 120 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = NULL;
 		}
-#line 1430 "albumtheme.c" /* yacc.c:1646  */
+#line 1431 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 123 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 124 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			/*if ($2 != NULL)
 				gth_parsed_doc_free ($2);*/
 			(yyval.list) = NULL;
 		}
-#line 1440 "albumtheme.c" /* yacc.c:1646  */
+#line 1441 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 130 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 131 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			if (g_str_equal ((yyvsp[-1].text), "thumbnail_caption")) {
 				(yyval.loop) = gth_loop_new (GTH_TAG_FOR_EACH_THUMBNAIL_CAPTION);
@@ -1453,11 +1454,11 @@ yyreduce:
 				YYERROR;
 			}
 		}
-#line 1457 "albumtheme.c" /* yacc.c:1646  */
+#line 1458 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 143 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 144 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.loop) = gth_range_loop_new ();
 			gth_range_loop_set_range (GTH_RANGE_LOOP ((yyval.loop)), (yyvsp[-5].text), (yyvsp[-3].expr), (yyvsp[-1].expr));
@@ -1466,60 +1467,60 @@ yyreduce:
 			gth_expr_unref ((yyvsp[-3].expr));
 			gth_expr_unref ((yyvsp[-1].expr));
 		}
-#line 1470 "albumtheme.c" /* yacc.c:1646  */
+#line 1471 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 153 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 154 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[-1].expr));
 		}
-#line 1478 "albumtheme.c" /* yacc.c:1646  */
+#line 1479 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 157 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 158 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[-2].expr));
 		}
-#line 1486 "albumtheme.c" /* yacc.c:1646  */
+#line 1487 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 162 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 163 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			gth_condition_add_document ((yyvsp[-2].cond), (yyvsp[-1].list));
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), (yyvsp[-2].cond));
 		}
-#line 1495 "albumtheme.c" /* yacc.c:1646  */
+#line 1496 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 167 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 168 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = NULL;
 		}
-#line 1503 "albumtheme.c" /* yacc.c:1646  */
+#line 1504 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 172 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 173 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[-1].expr));
 		}
-#line 1511 "albumtheme.c" /* yacc.c:1646  */
+#line 1512 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 176 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 177 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[-2].expr));
 		}
-#line 1519 "albumtheme.c" /* yacc.c:1646  */
+#line 1520 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 181 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 182 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr      *else_expr;
 			GthCondition *cond;
@@ -1531,27 +1532,27 @@ yyreduce:
 
 			(yyval.cond) = cond;
 		}
-#line 1535 "albumtheme.c" /* yacc.c:1646  */
+#line 1536 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 193 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 194 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.cond) = NULL;
 		}
-#line 1543 "albumtheme.c" /* yacc.c:1646  */
+#line 1544 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 204 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 205 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.tag) = gth_tag_new (GTH_TAG_SET_VAR, (yyvsp[-1].list));
 		}
-#line 1551 "albumtheme.c" /* yacc.c:1646  */
+#line 1552 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 209 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 210 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			if (gth_tag_get_type_from_name ((yyvsp[-2].text)) == GTH_TAG_EVAL) {
 				GthExpr *e;
@@ -1599,11 +1600,11 @@ yyreduce:
 				YYERROR;
 			}
 		}
-#line 1603 "albumtheme.c" /* yacc.c:1646  */
+#line 1604 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 257 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 258 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthTagType tag_type = gth_tag_get_type_from_name ((yyvsp[-2].text));
 			if (tag_type == GTH_TAG_INVALID) {
@@ -1612,89 +1613,89 @@ yyreduce:
 			}
 			(yyval.tag) = gth_tag_new (tag_type, (yyvsp[-1].list));
 		}
-#line 1616 "albumtheme.c" /* yacc.c:1646  */
+#line 1617 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 267 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 268 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), (yyvsp[-1].attribute));
 		}
-#line 1624 "albumtheme.c" /* yacc.c:1646  */
+#line 1625 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 271 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 272 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = NULL;
 		}
-#line 1632 "albumtheme.c" /* yacc.c:1646  */
+#line 1633 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 276 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 277 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[-4].text), (yyvsp[-1].expr));
 			g_free ((yyvsp[-4].text));
 		}
-#line 1641 "albumtheme.c" /* yacc.c:1646  */
+#line 1642 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 281 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 282 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.attribute) = gth_attribute_new_string ((yyvsp[-4].text), (yyvsp[-1].text));
 			g_free ((yyvsp[-4].text));
 			g_free ((yyvsp[-1].text));
 		}
-#line 1651 "albumtheme.c" /* yacc.c:1646  */
+#line 1652 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 287 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 288 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, 1);
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[0].text), e);
 			g_free ((yyvsp[0].text));
 		}
-#line 1662 "albumtheme.c" /* yacc.c:1646  */
+#line 1663 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 295 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 296 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend ((yyvsp[0].list), (yyvsp[-2].expr));
 		}
-#line 1670 "albumtheme.c" /* yacc.c:1646  */
+#line 1671 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 299 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 300 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = g_list_prepend (NULL, (yyvsp[0].expr));
 		}
-#line 1678 "albumtheme.c" /* yacc.c:1646  */
+#line 1679 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 303 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 304 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.list) = NULL;
 		}
-#line 1686 "albumtheme.c" /* yacc.c:1646  */
+#line 1687 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 308 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 309 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.expr) = (yyvsp[-1].expr);
 		}
-#line 1694 "albumtheme.c" /* yacc.c:1646  */
+#line 1695 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 312 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 313 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1707,11 +1708,11 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1711 "albumtheme.c" /* yacc.c:1646  */
+#line 1712 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 325 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 326 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1724,11 +1725,11 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1728 "albumtheme.c" /* yacc.c:1646  */
+#line 1729 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 338 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 339 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1741,11 +1742,11 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1745 "albumtheme.c" /* yacc.c:1646  */
+#line 1746 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 351 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 352 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1758,11 +1759,11 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1762 "albumtheme.c" /* yacc.c:1646  */
+#line 1763 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 364 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 365 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1775,11 +1776,11 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1779 "albumtheme.c" /* yacc.c:1646  */
+#line 1780 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 377 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 378 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1792,37 +1793,37 @@ yyreduce:
 
 			(yyval.expr) = e;
 		}
-#line 1796 "albumtheme.c" /* yacc.c:1646  */
+#line 1797 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 390 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 391 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			(yyval.expr) = (yyvsp[0].expr);
 		}
-#line 1804 "albumtheme.c" /* yacc.c:1646  */
+#line 1805 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 394 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 395 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			gth_expr_push_op ((yyvsp[0].expr), GTH_OP_NEG);
 			(yyval.expr) = (yyvsp[0].expr);
 		}
-#line 1813 "albumtheme.c" /* yacc.c:1646  */
+#line 1814 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 399 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 400 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			gth_expr_push_op ((yyvsp[0].expr), GTH_OP_NOT);
 			(yyval.expr) = (yyvsp[0].expr);
 		}
-#line 1822 "albumtheme.c" /* yacc.c:1646  */
+#line 1823 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 404 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 405 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     { /* function call */
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[-3].text));
@@ -1839,43 +1840,43 @@ yyreduce:
 			g_free ((yyvsp[-3].text));
 			(yyval.expr) = e;
 		}
-#line 1843 "albumtheme.c" /* yacc.c:1646  */
+#line 1844 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 421 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 422 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[0].text));
 			g_free ((yyvsp[0].text));
 			(yyval.expr) = e;
 		}
-#line 1854 "albumtheme.c" /* yacc.c:1646  */
+#line 1855 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 428 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 429 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_string (e, (yyvsp[-1].text));
 			g_free ((yyvsp[-1].text));
 			(yyval.expr) = e;
 		}
-#line 1865 "albumtheme.c" /* yacc.c:1646  */
+#line 1866 "albumtheme.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 435 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
+#line 436 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1646  */
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, (yyvsp[0].ivalue));
 			(yyval.expr) = e;
 		}
-#line 1875 "albumtheme.c" /* yacc.c:1646  */
+#line 1876 "albumtheme.c" /* yacc.c:1646  */
     break;
 
 
-#line 1879 "albumtheme.c" /* yacc.c:1646  */
+#line 1880 "albumtheme.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2103,7 +2104,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 442 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1906  */
+#line 443 "../../../extensions/webalbums/albumtheme.y" /* yacc.c:1906  */
 
 
 
@@ -2126,4 +2127,10 @@ gth_albumtheme_yyerror (const char *fmt, ...)
 }
 
 
+void
+gth_albumtheme_yyfatalerror (const char *msg)
+{
+	g_error ("%s", msg);
+}
+
 #include "albumtheme-lex.c"
